[Bug fortran/78611] -march=native makes code 3x slower
ubizjak at gmail dot com
gcc-bugzilla@gcc.gnu.org
Wed Nov 30 16:31:00 GMT 2016
https://gcc.gnu.org/bugzilla/show_bug.cgi?id=78611
--- Comment #9 from Uroš Bizjak <ubizjak at gmail dot com> ---
(In reply to H.J. Lu from comment #7)
> (In reply to H.J. Lu from comment #6)
> > Which glibc was used? You may run into:
> >
> > https://sourceware.org/bugzilla/show_bug.cgi?id=20495
>
> Please run your testcase with
>
> # LD_BIND_NOW=1 ./test
>
> with and without -mavx.
Yes, way faster with LD_BIND_NOW=1 in -mavx case:
[uros@localhost march]$ time ./a.out < ../bmtz
Slab or Bulk calculation?
input 1 for Slab or 0 for Bulk
Input the MTZ value from the substrate calculation
real 0m0.693s
user 0m0.691s
sys 0m0.002s
[uros@localhost march]$ LD_BIND_NOW=1 time ./a.out < ../bmtz
Slab or Bulk calculation?
input 1 for Slab or 0 for Bulk
Input the MTZ value from the substrate calculation
0.27user 0.00system 0:00.27elapsed 100%CPU (0avgtext+0avgdata 3012maxresident)k
0inputs+152outputs (0major+146minor)pagefaults 0swaps
More information about the Gcc-bugs
mailing list